@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 from django.core.management.base import BaseCommand, CommandError, make_option
-from django.utils import translation
-from django.conf import settings
+from django.core import management
 
-from data_migration.migration import Importer, Migrator
+import sys
 
 class Command(BaseCommand):
-    help = 'Migrates old data into the new django schema'
-    can_import_settings = True
+    help = 'DEPRECATED: Migrates old data into the new django schema'
 
     option_list = BaseCommand.option_list + (
         make_option('--commit',
@@ -29,12 +28,7 @@ class Command(BaseCommand):
     )
 
     def handle(self, *args, **options):
-        translation.activate(settings.LANGUAGE_CODE)
 
-        excluded_apps = options.get('excluded_apps', [])
-        Importer.import_all(excludes=excluded_apps)
-
-        Migrator.migrate(
-            commit=options.get('commit_changes', False),
-            log_queries=options.get('logquery', False)
-        )
+        sys.stderr.write(
+            u"This command is deprecated in favour of 'migrate_legacy_data'\n\n")
+        management.call_command('migrate_legacy_data', *args, **options)
